@@ -8,11 +8,6 @@ pub mod event_emitter;
 pub mod event_handler;
 pub mod event_processor;
 pub mod event_retriever;
-pub mod fs_completion_handler;
-pub mod fs_event_emitter;
-pub mod fs_event_retriever;
-pub mod fs_notify_consumer;
-pub mod local_service;
 pub mod local_sqs_service;
 pub mod redis_cache;
 pub mod retry;
@@ -20,3 +15,4 @@ pub mod s3_event_emitter;
 pub mod sqs_completion_handler;
 pub mod sqs_consumer;
 pub mod sqs_service;
+pub mod service_builder;
\ No newline at end of file
